@@ -15,7 +15,7 @@
  * either version 2 of the License, or (at your option) any later version.
  */
 
-#if !defined(__STDC_VERSION__) || (__STDC_VERSION__ < 199901L )
+#if !defined(_MSC_VER) && (!defined(__STDC_VERSION__) || (__STDC_VERSION__ < 199901L ))
 
 // ANSI C 1999/2000 stdint.h integer width declarations
 
@@ -162,17 +162,3 @@ typedef uint32_t   UINTN;
 
 #define uefi_call_wrapper(func, va_num, ...) func(__VA_ARGS__)
 #define EFI_FUNCTION
-
-static inline UINT64 DivU64x32(UINT64 Dividend, UINTN Divisor, UINTN *Remainder)
-{
-    /*
-     * GCC turns a division into a multiplication and shift with precalculated
-     * constants if the divisor is constant and the dividend fits into a 32 bit
-     * variable. Otherwise, it will turn this into calls into the 32-bit div
-     * library functions.
-     */
-    if (Remainder)
-        *Remainder = Dividend % Divisor;
-    Dividend = Dividend / Divisor;
-    return Dividend;
-}
